==> haskell-blaze-builder-0.4.0.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
key: blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Word Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Compat.Write
    Blaze.ByteString.Builder.Internal.Write
abi: c8c232d13e2833dbf946aa61886df706
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-builder-0.4.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-builder-0.4.0.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
key: blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Word Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Compat.Write
    Blaze.ByteString.Builder.Internal.Write
abi: add7ddc9595369637b605ba7657a0846
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-builder-0.4.0.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
depends:
    base-4.9.1.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
